﻿package src
{
	/**
	 * @author SVT Grafisk Center
	 */
	public class StringUtil
	{
		public static function isNullOrEmpty(input:String):Boolean
		{
			if (input == "" || input == null)
			{
				return true;
			}
			
			return false;
		}
		
		/**
		 * Does a case insensitive compare or two strings and returns true if they are equal.
		 * 
		 * @param stringOne The first string to compare.
		 * @param stringTwo The second string to compare.
		 *
		 * @returns A boolean value indicating whether the strings' values are equal in a case sensitive compare.      
		 */                      
		public static function areEqual(stringOne:String, stringTwo:String, caseSensitive:Boolean):Boolean
		{
			if (caseSensitive)
			{
				return (stringOne == stringTwo);
			}
			else
			{
				return (stringOne.toLowerCase() == stringTwo.toLowerCase());
			}
		}
     
		/**
		 * Determines whether the specified string begins with the spcified prefix.
		 * 
		 * @param input The string that the prefix will be checked against.
		 * @param prefix The prefix that will be tested against the string.
		 *
		 * @returns True if the string starts with the prefix, false if it does not.
		 */      
		public static function beginsWith(input:String, prefix:String):Boolean
		{                       
			return (prefix == input.substring(0, prefix.length));
		}

		/**
		 * Determines whether the specified string ends with the spcified suffix.
		 * 
		 * @param input The string that the suffic will be checked against.
		 * @param prefix The suffic that will be tested against the string.
		 *
		 * @returns True if the string ends with the suffix, false if it does not.
		 */      
		public static function endsWith(input:String, suffix:String):Boolean
		{
			return (suffix == input.substring(input.length - suffix.length));
		}
		
		/**
		 * Removes whitespace from the front and the end of the specified string.
		 * 
		 * @param input The String whose beginning and ending whitespace will will be removed.
		 *
		 * @returns A String with whitespace removed from the begining and end     
		 */                      
		public static function trim(input:String):String
		{
			return StringUtil.ltrim(StringUtil.rtrim(input));
		}

		/**
		 * Removes whitespace from the front of the specified string.
		 * 
		 * @param input The String whose beginning whitespace will will be removed.
		 *
		 * @returns A String with whitespace removed from the begining     
		 */      
		public static function ltrim(input:String):String
		{
			var length:Number = input.length;
			
			for (var i:Number = 0; i < length; i++)
			{
				if (input.charCodeAt(i) > 32)
				{
					return input.substring(i);
				}
			}
			
			return "";
		}

		/**
		 * Removes whitespace from the end of the specified string.
		 * 
		 * @param input The String whose ending whitespace will will be removed.
		 *
		 * @returns A String with whitespace removed from the end  
		 */      
		public static function rtrim(input:String):String
		{
			var length:Number = input.length;
			
			for (var i:Number = length; i > 0; i--)
			{
				if (input.charCodeAt(i - 1) > 32)
				{
					return input.substring(0, i);
				}
			}
			
			return "";
		}
	}
}